@@ -1,9 +1,9 @@
 CVbinary <-
-function (obj, rand = NULL, nfolds = 10, print.details = TRUE) 
+function (obj, rand = NULL, nfolds = 10, print.details = TRUE)
 {
     data <- obj$data
     m <- dim(data)[1]
-    if (is.null(rand)) 
+    if (is.null(rand))
         rand <- sample(nfolds, m, replace = TRUE)
     form <- formula(obj)
     yvar <- all.vars(form)[1]
@@ -12,16 +12,16 @@ function (obj, rand = NULL, nfolds = 10, print.details = TRUE)
     fam <- obj$family$family
     hat <- predict(glm(form, data, family = fam), type = "response")
     cvhat <- rep(0, length(rand))
-    if (print.details) 
+    if (print.details)
         cat("\nFold: ")
     for (i in ival) {
-        if (print.details) 
+        if (print.details)
             cat("", i)
-        if (i%%20 == 0) 
+        if (i%%20 == 0)
             cat("\n")
         here <- i != rand
         i.glm <- glm(form, data = data[here, ], family = fam)
-        cvhat[!here] <- predict(i.glm, newdata = data[!here, 
+        cvhat[!here] <- predict(i.glm, newdata = data[!here,
             ], family = fam, type = "response")
     }
     if (is.factor(obs)) {
@@ -36,12 +36,12 @@ function (obj, rand = NULL, nfolds = 10, print.details = TRUE)
         acc.cv <- sum(obs == round(cvhat))/m
     }
     if (print.details) {
-        cat("\nInternal estimate of accuracy =", round(acc.internal, 
+        cat("\nInternal estimate of accuracy =", round(acc.internal,
             3))
-        cat("\nCross-validation estimate of accuracy =", round(acc.cv, 
+        cat("\nCross-validation estimate of accuracy =", round(acc.cv,
             3))
         cat("\n")
     }
-    invisible(list(cv = cvhat, internal = hat, acc.cv = acc.cv, 
+    invisible(list(cvhat = cvhat, internal = hat, acc.cv = acc.cv,
         acc.internal = acc.internal))
 }
